from .base import Color

PRESET_RED_RGB = Color((255, 0, 0), "rgb")
PRESET_ORANGE_RGB = Color((255, 165, 0), "rgb")
PRESET_YELLOW_RGB = Color((255, 255, 0), "rgb")
PRESET_GREEN_RGB = Color((0, 128, 0), "rgb")
PRESET_BLUE_RGB = Color((0, 0, 255), "rgb")
PRESET_PURPLE_RGB = Color((128, 0, 128), "rgb")
PRESET_VIOLET_RGB = Color((143, 0, 255), "rgb")
PRESET_PINK_RGB = Color((255, 192, 203), "rgb")
PRESET_BROWN_RGB = Color((165, 42, 42), "rgb")
PRESET_GRAY_RGB = Color((128, 128, 128), "rgb")
PRESET_WHITE_RGB = Color((255, 255, 255), "rgb")
PRESET_BLACK_RGB = Color((0, 0, 0), "rgb")
PRESET_RED_RGBA = Color((255, 0, 0, 1.0), "rgba")
PRESET_ORANGE_RGBA = Color((255, 165, 0, 1.0), "rgba")
PRESET_YELLOW_RGBA = Color((255, 255, 0, 1.0), "rgba")
PRESET_GREEN_RGBA = Color((0, 128, 0, 1.0), "rgba")
PRESET_BLUE_RGBA = Color((0, 0, 255, 1.0), "rgba")
PRESET_PURPLE_RGBA = Color((128, 0, 128, 1.0), "rgba")
PRESET_VIOLET_RGBA = Color((143, 0, 255, 1.0), "rgba")
PRESET_PINK_RGBA = Color((255, 192, 203, 1.0), "rgba")
PRESET_BROWN_RGBA = Color((165, 42, 42, 1.0), "rgba")
PRESET_GRAY_RGBA = Color((128, 128, 128, 1.0), "rgba")
PRESET_WHITE_RGBA = Color((255, 255, 255, 1.0), "rgba")
PRESET_BLACK_RGBA = Color((0, 0, 0, 1.0), "rgba")
PRESET_RED_HSL = Color((0, 1, 0.5), "hsl")
PRESET_ORANGE_HSL = Color((30, 1, 0.5), "hsl")
PRESET_YELLOW_HSL = Color((60, 1, 0.5), "hsl")
PRESET_GREEN_HSL = Color((120, 1, 0.25), "hsl")
PRESET_BLUE_HSL = Color((240, 1, 0.5), "hsl")
PRESET_PURPLE_HSL = Color((300, 1, 0.25), "hsl")
PRESET_VIOLET_HSL = Color((270, 1, 0.5), "hsl")
PRESET_PINK_HSL = Color((350, 1, 0.88), "hsl")
PRESET_BROWN_HSL = Color((30, 0.59, 0.41), "hsl")
PRESET_GRAY_HSL = Color((0, 0, 0.5), "hsl")
PRESET_WHITE_HSL = Color((0, 0, 1), "hsl")
PRESET_BLACK_HSL = Color((0, 0, 0), "hsl")